package com.lqkj.link.module.authority.service;

import com.lqkj.link.module.authority.domain.UserInfo;
import com.lqkj.link.module.authority.repository.UserInfoRepository;
import com.lqkj.link.util.RSAUtils;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

import java.util.Date;

@Service
public class DatabaseUserDetailService implements UserDetailsService {

    private final UserInfoRepository userInfoRepository;

    public DatabaseUserDetailService(UserInfoRepository userInfoRepository) {
        this.userInfoRepository = userInfoRepository;
    }

    @Override
    public UserDetails loadUserByUsername(String username) throws UsernameNotFoundException {
        if (username.length() != 172) throw new UsernameNotFoundException("用户名错误！");
        try {
            username = RSAUtils.decryptBase64(username);
        } catch (Exception e) {
            throw new UsernameNotFoundException("用户名错误！");
        }
        UserInfo userInfo = userInfoRepository.findByUserCode(username);
        if (userInfo == null) {
            throw new UsernameNotFoundException("用户名不存在！");
        }
        return userInfo;
    }

    /**
     * 账号是否锁定
     * @param userCode
     * @return
     */
    @Transactional
    public boolean isLocked(String userCode) {
        UserInfo userInfo = userInfoRepository.findByUserCode(userCode);
        if (userInfo == null){
            return false;
        }else {
            if (userInfo.getLocking()) {
                if (new Date().getTime() - userInfo.getLockTime().getTime() > 1000 * 60 * 60){
                    userInfoRepository.cleanLockStatus(userInfo.getUserId());
                    return false;
                }else{
                    return true;
                }
            }else{
                return false;
            }
        }
    }

    /**
     * 更新登录错误次数
     * @param userCode
     * @return
     */
    @Transactional
    public String lockedUser(String userCode){
        UserInfo userInfo = userInfoRepository.findByUserCode(userCode);
        if (userInfo == null){
            return "用户名或密码错误";
        }else{
            int loginErrorCount = userInfo.getLoginErrorCount() == null ? 0 : userInfo.getLoginErrorCount();
            loginErrorCount += 1;
            userInfo.setLoginErrorCount(loginErrorCount);
            if (loginErrorCount == 4){
                userInfo.setLocking(true);
                userInfo.setLockTime(new Date());
                userInfoRepository.save(userInfo);
                return "账号已被冻结,请稍后重试";
            }
            userInfoRepository.save(userInfo);
            return "用户名或密码错误," + (4 - loginErrorCount) +"次错误后,账号将会冻结1小时";
        }
    }

    /**
     * 解锁用户
     * @param userCode
     */
    @Transactional
    public void unlockedUser(String userCode){
        UserInfo userInfo = userInfoRepository.findByUserCode(userCode);
        userInfoRepository.cleanLockStatus(userInfo.getUserId());
    }

    public UserInfo findByUserCode(String userCode) {
        return userInfoRepository.findByUserCode(userCode);
    }

}
