package com.lqkj.link.module.bulletin.controller;

import com.lqkj.link.message.MessageBean;
import com.lqkj.link.message.MessageListBean;
import com.lqkj.link.module.bulletin.domain.BulletinInfo;
import com.lqkj.link.module.bulletin.service.BulletinInfoService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/bulletin")
@Tag(name = "通知公告接口", description = "通知公告接口")
public class BulletinInfoController {
    private final BulletinInfoService bulletinInfoService;

    public BulletinInfoController(BulletinInfoService bulletinInfoService) {
        this.bulletinInfoService = bulletinInfoService;
    }

    @Operation(
            summary = "5.1.3.21 通知公告列表接口",
            description = "5.1.3.21 通知公告列表接口"
    )
    @PostMapping("/manage/all")
    public MessageListBean<BulletinInfo> queryAll() {
        return MessageListBean.ok(bulletinInfoService.queryAll(), "通知公告列表接口");
    }

    @Operation(
            summary = "5.1.3.22 通知公告保存接口",
            description = "5.1.3.22 通知公告保存接口",
            requestBody = @io.swagger.v3.oas.annotations.parameters.RequestBody(
                    description = "通知公告信息实体",
                    required = true,
                    content = @Content(
                            mediaType = "application/json",
                            schema = @Schema(implementation = BulletinInfo.class)
                    )
            )
    )
    @PostMapping("/manage/save")
    public MessageBean save(@RequestBody BulletinInfo info) {
        bulletinInfoService.save(info);
        return MessageBean.ok(null, "通知公告保存接口");
    }

    @Operation(
            summary = "5.1.3.23 通知公告删除接口",
            description = "5.1.3.23 通知公告删除接口",
            parameters = {
                    @Parameter(name = "infoId", description = "信息ID")
            }
    )
    @PostMapping("/manage/delete")
    public MessageBean delete(@RequestParam Integer infoId) {
        bulletinInfoService.delete(infoId);
        return MessageBean.ok(null, "通知公告删除接口");
    }
}
