package com.lqkj.link.module.zone.controller;

import com.lqkj.link.message.MessageBean;
import com.lqkj.link.message.MessageListBean;
import com.lqkj.link.module.base.service.BaseService;
import com.lqkj.link.module.zone.domain.GeomInfo;
import com.lqkj.link.module.zone.domain.OneZoneGeomInfos;
import com.lqkj.link.module.zone.service.GeomInfoService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

import static com.lqkj.link.APIVersion.VERSION_V1;
import static com.lqkj.link.APIVersion.VERSION_V2;

@RestController
@RequestMapping("/geom")
@Tag(name = "场景元素信息", description = "场景元素信息")
public class GeomInfoController {
    private final GeomInfoService geomInfoService;
    private final BaseService baseService;

    public GeomInfoController(GeomInfoService geomInfoService, BaseService baseService) {
        this.geomInfoService = geomInfoService;
        this.baseService = baseService;
    }

    @Operation(
            summary = "5.1.2.8 下载场景信息接口",
            description = "5.1.2.8 下载场景信息接口",
            parameters = {
                    @Parameter(name = "zoneId", required = true, description = "作品/区域ID")
            }
    )
    @PostMapping("/" + VERSION_V1 + "/byZone")
    public List<GeomInfo> findByZone(@RequestParam Integer zoneId) {
        return geomInfoService.findAllByZoneId(zoneId);
    }

    @Operation(
            summary = "5.1.2.33 下载场景信息接口V2",
            description = "5.1.2.33 下载场景信息接口V2",
            parameters = {
                    @Parameter(name = "zoneId", required = true, description = "作品/区域ID")
            }
    )
    @PostMapping("/" + VERSION_V2 + "/byZone")
    public MessageListBean<GeomInfo> findByZoneV2(@RequestParam Integer zoneId) {
        return MessageListBean.ok(geomInfoService.findAllByZoneId(zoneId), "下载场景信息接口");
    }

    @Operation(
            summary = "5.1.2.23 保存场景信息",
            description = "5.1.2.23 保存场景信息",
            requestBody = @io.swagger.v3.oas.annotations.parameters.RequestBody(
                    description = "场景元素信息",
                    required = true,
                    content = @Content(
                            mediaType = "application/json",
                            schema = @Schema(implementation = OneZoneGeomInfos.class)
                    )
            )
    )
    @PostMapping("" + VERSION_V1 + "/saveGeom")
    public MessageBean saveGeom(@RequestBody OneZoneGeomInfos geomInfos) {
        geomInfoService.saveLayerByZone(geomInfos);
        geomInfoService.saveGeomByZone(geomInfos);
        return MessageBean.ok(null,"保存场景信息");
    }

    @Operation(
            summary = "5.1.3.28 创作中心上传图片文件",
            description = "5.1.3.28 创作中心上传图片文件",
            parameters = {
                    @Parameter(name = "file", description = "图标文件", required = true)
            }
    )
    @PostMapping("/" + VERSION_V1 + "/uploadImg")
    public MessageBean<String> uploadImg(MultipartFile file) {
        return baseService.uploadImg(file, "zone/img/");
    }

    @Operation(
            summary = "5.1.3.29 创作中心上传音频文件",
            description = "5.1.3.29 创作中心上传音频文件",
            parameters = {
                    @Parameter(name = "file", description = "音频文件", required = true)
            }
    )
    @PostMapping("/" + VERSION_V1 + "/uploadAudio")
    public MessageBean<String> uploadAudio(@RequestParam MultipartFile file) {
        return baseService.uploadAudio(file, "zone/audio/");
    }

    @Operation(
            summary = "5.1.3.30 创作中心上传视频文件",
            description = "5.1.3.30 创作中心上传视频文件",
            parameters = {
                    @Parameter(name = "file", description = "视频文件", required = true)
            }
    )
    @PostMapping("/" + VERSION_V1 + "/uploadVideo")
    public MessageBean<String> uploadVideo(@RequestParam MultipartFile file) {
        return baseService.uploadVideo(file, "zone/video/");
    }
}
